/*
 *   Copyright 2017-2020, Schlumberger
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package org.opengroup.osdu.notification.api;

import org.opengroup.osdu.core.common.http.HttpResponse;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.notification.provider.interfaces.IPubsubRequestBodyExtractor;
import org.opengroup.osdu.notification.service.NotificationHandler;
import org.opengroup.osdu.notification.utils.Config;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.annotation.RequestScope;

import java.util.Map;

@RestController
@RequestScope
@RequestMapping("/push-handlers")
public class PubsubEndpoint {
    @Autowired
    private IPubsubRequestBodyExtractor pubsubRequestBodyExtractor;
    @Autowired
    private NotificationHandler notificationHandler;
    @Autowired
    private JaxRsDpsLog log;

    private final String ACKNOWLEDGE = "message acknowledged by client";
    private final String NOT_ACKNOWLEDGE = "message not acknowledged by client";

    @PostMapping("/records-changed")
    @PreAuthorize("@authorizationFilter.hasAnyPermission('" + Config.OPS + "', '" + Config.PUBSUB + "')")
    public ResponseEntity recordChanged() throws Exception {
        String notificationId = this.pubsubRequestBodyExtractor.extractNotificationIdFromRequestBody();
        String pubsubMessage = this.pubsubRequestBodyExtractor.extractDataFromRequestBody();
        Map<String, String> headerAttributes = this.pubsubRequestBodyExtractor.extractAttributesFromRequestBody();
        HttpResponse response = notificationHandler.notifySubscriber(notificationId, pubsubMessage, headerAttributes);
        if (!response.isSuccessCode()) {
            this.log.error(NOT_ACKNOWLEDGE + response.getBody());
            return new ResponseEntity<String>(NOT_ACKNOWLEDGE, HttpStatus.valueOf(response.getResponseCode()));
        }
        this.log.debug(ACKNOWLEDGE);
        return new ResponseEntity<String>(ACKNOWLEDGE, HttpStatus.OK);
    }
}
