/*
 *   Copyright 2017-2020, Schlumberger
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.opengroup.osdu.notification.auth.factory;

import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.notification.auth.GsaAuth;
import org.opengroup.osdu.notification.auth.HmacAuth;
import org.opengroup.osdu.notification.auth.interfaces.SecretAuth;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.annotation.RequestScope;

@Component
public class AuthFactory {
    private final String HMAC_TYPE = "HMAC";
    private final String GSA_TYPE = "GSA";

    @Autowired
    private HmacAuth hmacAuth;
    @Autowired
    private GsaAuth gsaAuth;
    @Autowired
    private JaxRsDpsLog log;

    public SecretAuth getSecretAuth(String secretType) {
        switch (secretType.toUpperCase()) {
            case HMAC_TYPE:
                return hmacAuth;
            case GSA_TYPE:
                return gsaAuth;
            default:
                throw new AppException(404, "Secret Type Not Found", "Unrecognised secret type encountered :" + secretType);
        }
    }
}
