// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.auth.factory;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.notification.auth.GsaAuth;
import org.opengroup.osdu.notification.auth.HmacAuth;
import org.opengroup.osdu.notification.auth.interfaces.SecretAuth;

import static org.junit.Assert.assertTrue;

@RunWith(MockitoJUnitRunner.class)
public class AuthFactoryTest {

    @InjectMocks
    AuthFactory authFactory;

    @Mock
    private HmacAuth hmacAuth;

    @Mock
    private GsaAuth gsaAuth;

    @Before
    public void setup() {
        MockitoAnnotations.initMocks(AuthFactoryTest.this);
    }

    @Test(expected = AppException.class)
    public void getSecretAuthTest_invalidType() {
        authFactory.getSecretAuth("invalid");
    }

    @Test
    public void getSecretAuthTest_gsaAuth() {
        SecretAuth secretAuth = authFactory.getSecretAuth("GSA");
        assertTrue(secretAuth instanceof GsaAuth);
    }

    @Test
    public void getSecretAuthTest_hmacAuth() {
        SecretAuth secretAuth = authFactory.getSecretAuth("HMAC");
        assertTrue(secretAuth instanceof HmacAuth);
    }
}
