/*
 *   Copyright 2017-2020, Schlumberger
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package org.opengroup.osdu.notification.di;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.Spy;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.notification.provider.interfaces.IAppProperties;
import org.opengroup.osdu.notification.provider.interfaces.IPubsubRequestBodyExtractor;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.powermock.api.mockito.PowerMockito.when;

@RunWith(MockitoJUnitRunner.class)
public class RequestInfoExtTest {

    Map<String, String> httpHeaders;

    @Mock
    DpsHeaders headers;

    @Mock
    IPubsubRequestBodyExtractor requestBodyExtractor;

    @Mock
    private IAppProperties config;

    @Mock
    private HttpServletRequest http;

    @Spy
    @InjectMocks
    private RequestInfoExt sut;

    @Before
    public void setup() {
        httpHeaders = new HashMap<>();
        httpHeaders.put("authorization", "aaa");
        httpHeaders.put("correlation-id", "cor123");
        httpHeaders.put("context", "67890");
        httpHeaders.put("data-partition-id", "123");
        MockitoAnnotations.initMocks(RequestInfoExtTest.this);
    }

    @Test
    public void assignPartitionIdIfNotInHeaderTest() {
        when(http.getMethod()).thenReturn("POST");
        when(headers.getPartitionId()).thenReturn(null);
        when(requestBodyExtractor.extractAttributesFromRequestBody()).thenReturn(httpHeaders);
        this.sut.assignPartitionIdIfNotInHeader();
        verify(requestBodyExtractor, times(1)).extractAttributesFromRequestBody();
    }

}
