// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.provider.azure.messageBus.extractor;

import com.microsoft.azure.servicebus.IMessage;
import org.opengroup.osdu.notification.provider.azure.models.NotificationContent;
import org.opengroup.osdu.notification.provider.azure.messageBus.interfaces.IPullRequestBodyExtractor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.stereotype.Component;

import java.util.Map;

@Component
@ConditionalOnExpression("${azure.serviceBus.enabled:true} || ${azure.eventGridToServiceBus.enabled:true}")
public class RequestBodyAdapter {
    @Autowired
    IPullRequestBodyExtractor extractor;

    public NotificationContent extractNotificationContent(IMessage message, String subscriptionName) {

        extractor.InitializeExtractor(message);
        String notificationData = extractor.extractDataFromRequestBody();
        Map<String, String> headerAttributes = extractor.extractAttributesFromRequestBody();
        NotificationContent notificationContent = NotificationContent.mapFrom(subscriptionName, notificationData, headerAttributes, false);
        return notificationContent;
    }
}
